body.nbp-presenting {
  .nbpresent_speaker{
    .nbp-ui();

    z-index: @z-speaker;
    display: block;
    position: fixed;
    bottom: 10px;
    right: @app-bar-width;

    .nbp-presenter-toolbar {
      transition: all 0.2s;
      float: right;

      &:hover, &.fake_hover{
        opacity: 1;
        transition: all 0.2s;
      }

      a {
        color: @jpy-brand;
      }
    }
  }
}

body:not(.nbp-presenting) .nbpresent_speaker{
  display: none;
}
