export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
export ARCH="64"
export PREFIX="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
export BUILD_PREFIX="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
export SYS_PREFIX="/opt/conda"
export SYS_PYTHON="/opt/conda/bin/python"
export SUBDIR="osx-64"
export SRC_DIR="/opt/conda/conda-bld/nbpresent_1530883839427/work"
export ROOT="/opt/conda"
export CONDA_PY="27"
export PY3K="0"
export PY_VER="2.7"
export STDLIB_DIR="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/python2.7"
export SP_DIR="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/python2.7/site-packages"
export PYTHON="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python"
export NPY_VER="1.11"
export CONDA_NPY="111"
export PERL_VER="5.26"
export CONDA_PERL="5.26"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.4"
export CONDA_R="3.4"
export PKG_NAME="nbpresent"
export PKG_VERSION="3.0.2"
export PKG_BUILDNUM="1"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/Users/rdonnelly/conda/aggregate/nbpresent-feedstock/recipe"
export CPU_COUNT="8"
export LANG="en_GB.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla:/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin:/opt/conda/bin:/Users/rdonnelly/miniconda3/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/opt/X11/bin"
export HOME="/Users/rdonnelly"
export PKG_CONFIG_PATH="/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="x86_64"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export BUILD="x86_64-apple-darwin13.4.0"
export r_base="3.4"
export cpu_optimization_target="nocona"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export target_platform="osx-64"
export c_compiler="clang"
export cxx_compiler="clangxx"
export fortran_compiler="gfortran"
export noarch_python="False"
export apr="1.6.3"
export blas_impl="openblas"
export boost="1.67"
export bzip2="1.0"
export cairo="1.14"
export CONDA_BUILD_SYSROOT="/opt/MacOSX10.9.sdk"
export VERBOSE_AT="V=1"
export VERBOSE_CM="VERBOSE=1"
export dbus="1"
export expat="2.2"
export fontconfig="2.13"
export freetype="2.9"
export g2clib="1.6"
export gstreamer="1.14"
export gst_plugins_base="1.14"
export geos="3.6.2"
export giflib="5.1"
export glib="2.56"
export gmp="6.1"
export harfbuzz="1.7"
export hdf4="4.2"
export hdf5="1.10"
export hdfeos2="2.19"
export hdfeos5="5.1"
export icu="58"
export jpeg="9"
export libdap4="3.19"
export libffi="3.2"
export libgdal="2.2"
export libgsasl="1.8"
export libkml="1.3"
export libnetcdf="4.6"
export libpng="1.6"
export libtiff="4.0"
export libxml2="2.9"
export libxslt="1.1"
export lzo="2"
export macos_min_version="10.9"
export macos_machine="x86_64-apple-darwin13.4.0"
export mkl="2018"
export mpfr="4"
export openblas="0.2.20"
export openjpeg="2.3"
export openssl="1.0.2"
export pixman="0.34"
export proj4="5"
export libprotobuf="3.5.2"
export r_version="3.5.0"
export r_implementation="r-base"
export serf="1.3.9"
export sqlite="3"
export tk="8.6"
export zlib="1.2"
export xz="5"
export qtwebkit="true"
export ignore_build_only_deps="numpy"
export pin_run_as_build="OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x.x'), ('max_pin', 'x.x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
export CONDA_BUILD_STATE="BUILD"
source "/opt/conda/bin/activate" "/opt/conda/conda-bld/nbpresent_1530883839427/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla"
npm install
npm run build:release
rm -rf node_modules
"${PYTHON}" setup.py install --single-version-externally-managed --record=record.txt
"${PREFIX}/bin/jupyter-nbextension" install nbpresent --py --sys-prefix --overwrite
